@@ -1,9 +1,15 @@
+from django.core.cache import cache
 from django.db import models
 
 class Country(models.Model):
     country_code = models.CharField(max_length=2, unique=True) # ISO standard
     country_name = models.CharField(max_length=100, default="")
 
+    def save(self, *args, **kwargs):
+        super(Country, self).save(*args, **kwargs)
+        cache.delete('country_block_settings')
+        cache.delete('country_block_allowed_countries')
+
     def __unicode__(self):
         return "(%s) %s" % (self.country_code, self.country_name)
 
@@ -18,5 +24,10 @@ class Settings(models.Model):
     staff_user_country = models.ForeignKey(Country, related_name='staff_user_settings')
     local_ip_user_country = models.ForeignKey(Country, related_name='local_ip_user_settings')
 
+    def save(self, *args, **kwargs):
+        super(Settings, self).save(*args, **kwargs)
+        cache.delete('country_block_settings')
+        cache.delete('country_block_allowed_countries')
+
     def __unicode__(self):
         return "%s settings" % self.location
\ No newline at end of file
